@@ -1,6 +1,8 @@
 from flask_sketch.handlers.app_type_handler import app_type_handler
 from flask_sketch.handlers.database_handler import database_handler
+from flask_sketch.handlers.models_handler import models_handler
 from flask_sketch.handlers.auth_handler import auth_handler
+from flask_sketch.handlers.commands_handler import commands_handler
 from flask_sketch.handlers.api_auth_handler import api_auth_handler
 from flask_sketch.handlers.api_framework_handler import api_framework_handler
 from flask_sketch.handlers.config_handler import config_handler
@@ -9,7 +11,9 @@ from flask_sketch.handlers.features_handler import handle_features
 __all__ = [
     "app_type_handler",
     "database_handler",
+    "models_handler",
     "auth_handler",
+    "commands_handler",
     "api_auth_handler",
     "api_framework_handler",
     "config_handler",
