@@ -1,4 +1,5 @@
 from flask_sketch.utils import has_answers
+from flask_sketch.const import FLASK_LOGIN, FLASK_SECURITY, NONE
 
 auth_framework_questions = [
     {
@@ -8,10 +9,10 @@ auth_framework_questions = [
         "choices": [
             {
                 "name": "Flask-Security-Too (aka Flask-Security)",
-                "value": "security",
+                "value": FLASK_SECURITY,
             },
-            {"name": "Flask-Login", "value": "login"},
-            {"name": "None", "value": "none"},
+            {"name": "Flask-Login", "value": FLASK_LOGIN},
+            {"name": "None", "value": NONE},
         ],
         "validate": lambda answer: "You must choose at least one topping."
         if len(answer) == 0
